
var width = 750,
    height = 300,
    pad = 20,
    leftPad = 70;

var svg = d3.select("#results")
  .append("svg")
  .attr("width", width)
  .attr("height", height);
  
var x = d3.scale
  .ordinal()
  .rangeRoundBands([leftPad, width - pad], 0.1);
var y = d3.scale
  .linear()
  .range([height - pad, pad]);

var xAxis = d3.svg.axis()
  .scale(x)
  .orient("bottom");
var yAxis = d3.svg.axis()
  .scale(y)
  .orient("left");
  
var reload = function() {
  d3.tsv('afcw-results.tsv', function(results) {
    redraw(results);
  });
};

var redraw = function(data) {
  x.domain(data.map(function(d, i) { return i; }));
  y.domain([0, d3.max(data, function(d) { return d.GoalsScored; })]);
  
  var bars = svg.selectAll(".bar").data(data);
  
  bars.enter()
    .append("rect")
    .classed("bar", true);
  
  bars
    .attr("x", function(d, i) { return x(i); })
    .attr("width", x.rangeBand())
    .attr("y", y(0))
    .attr("height", 0)
    .transition()
    .delay(function(d, i) { return i * 50; })
    .duration(800)
    .attr("y", function(d) { return y(d.GoalsScored); })
    .attr("height", function(d) { return y(0) - y(d.GoalsScored); });
  
  var axes = [
    {axis: xAxis, translateX: 0, translateY: (height - pad), clazz: "x"},
    {axis: yAxis, translateX: leftPad, translateY: 0, clazz: "y"}
  ];
  
  var axis = svg.selectAll("g.axis")
    .data(axes)
  
  axis.enter()
    .append("g")
    .classed("axis", true);
    
  axis.each(function(d) {
    d3.select(this)
      .attr("transform", "translate(" + d.translateX + "," + d.translateY + ")")
      .classed(d.clazz, true)
      .call(d.axis);
  });
};

reload();
