
var width = 750,
    height = 500,
    pad = 20,
    leftPad = 70
    bottomPad = 70;

var svg = d3.select("#standings-chart")
  .append("svg")
  .attr("width", width)
  .attr("height", height);

var x = d3.time.scale().range([leftPad, width - pad]);
var y = d3.scale.linear().range([height - bottomPad, pad]);

var parseDate = d3.time.format("%Y-%m-%d").parse;

var xAxis = d3.svg.axis()
  .scale(x)
  .orient("bottom")
  .ticks(d3.time.weeks, 1)
  .tickFormat(d3.time.format("%b %d"));
var yAxis = d3.svg.axis()
  .scale(y)
  .orient("left");

var pointLine = d3.svg.line()
  .x(function(d) { return x(d.date); })
  .y(function(d) { return y(d.points); });

var reload = function() {
  d3.json('eng2-2013-14.json', function(json) {
    teams = [];
    json.forEach(function(d) {
      d.Date = parseDate(d.Date);
      d.Games.forEach(function(g) {
	      var awayPoints = (g.AwayScore===g.HomeScore)? 1
	        : (g.AwayScore < g.HomeScore)? 0:3;
	      var awayData = {date: d.Date, points: awayPoints, team: 
	        g.Away, opp: g.Home, goals: g.AwayScore, allowed: g.HomeScore,
	        align: "away", venue: g.Venue,
	        decision: (awayPoints==3)? "win":(awayPoints==1)? "draw":"loss"
	      };
	      if (teams.indexOf(g.Away) < 0) {
	        teams.push(g.Away);
	        teams[g.Away] = [awayData];
	      } else {
	        lastIndex = teams[g.Away].length -1;
	        awayData.points += teams[g.Away][lastIndex].points;
	        teams[g.Away].push(awayData);
	      }
	      
	      var homePoints = (g.HomeScore===g.AwayScore)? 1
	        : (g.HomeScore < g.AwayScore)? 0:3;
	      var homeData = {date: d.Date, points: homePoints, team: 
	        g.Home, opp: g.Away, goals: g.HomeScore, allowed: g.AwayScore,
	        align: "home", venue: g.Venue,
	        decision: (homePoints==3)? "win":(homePoints==1)? "draw":"loss"
	      };
	      if (teams.indexOf(g.Home) < 0) {
	        teams.push(g.Home);
	        teams[g.Home] = [homeData];
	      } else {
	        lastIndex = teams[g.Home].length -1;
	        homeData.points += teams[g.Home][lastIndex].points;
	        teams[g.Home].push(homeData);
	      }
	    });
    });

    x.domain([json[0].Date, json[json.length -1].Date]);
    y.domain([0, 100]);
    
    //console.log(teams);
    redraw(teams);
  });
};

var redraw = function(data) {
  var lines = svg.selectAll(".line-graph")
    .data(data)
  
  lines.enter()
    .append("g")
    .attr("class", "line-graph")
    .attr("transform", "translate(" + xAxis.tickPadding() + ", 0)");
  
  var path = lines.append("path")
    .datum(function(d) { return data[d]; })
    .attr("d", function(d) { return pointLine(d); });

  var axes = [
    {axis: xAxis, translateX: 0, translateY: (height - bottomPad), clazz: "x"},
    {axis: yAxis, translateX: leftPad, translateY: 0, clazz: "y"},
  ];
  
  var axis = svg.selectAll("g.axis")
    .data(axes)
  
  axis.enter()
    .append("g")
    .classed("axis", true);
    
  axis.each(function(d) {
    d3.select(this)
      .attr("transform", "translate(" + d.translateX + "," + d.translateY + ")")
      .classed(d.clazz, true)
      .call(d.axis);
  });
  
  axis.selectAll(".x text")
    .style("text-anchor", "end")
    .attr({dx: "-0.8em", dy: "0.15em", transform: "rotate(-65)"});
  
};

reload();
